#
# spec file for package emacs-magit
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           emacs-magit
Version:        2.13.0
Release:        9.2
Summary:        Git interaction mode for emacs
License:        GPL-3.0-or-later
Group:          Productivity/Editors/Emacs
Url:            https://github.com/magit/magit/
Source0:        https://github.com/magit/magit/releases/download/%{version}/magit-%{version}.tar.gz
BuildRequires:  emacs-dash
BuildRequires:  emacs-ghub
BuildRequires:  emacs-magit-popup
BuildRequires:  emacs-nox
BuildRequires:  emacs-with-editor > 2.5.0
BuildRequires:  git-core
BuildRequires:  make
BuildRequires:  makeinfo
Requires:       emacs
Requires:       emacs-dash
Requires:       emacs-ghub
Requires:       emacs-magit-popup
Requires:       emacs-with-editor > 2.5.0
Requires:       git-core
Requires(post): %{install_info_prereq}
Requires(preun): %{install_info_prereq}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%define _lispdir %{_datadir}/emacs/site-lisp/
%define _magit_make make PREFIX=%{_prefix} DESTDIR=%{buildroot} lispdir=%{_lispdir} LOAD_PATH="-L %{_lispdir} -L ./lisp -L ."

%description
Magit is an interface to the version control system Git, implemented as an
Emacs package. Magit aspires to be a complete Git porcelain. While we
cannot (yet) claim that Magit wraps and improves upon each and every Git
command, it is complete enough to allow even experienced Git users to perform
almost all of their daily version control tasks directly from within Emacs.

%prep
%setup -q -n magit-%{version}

%build
%{_magit_make} -C lisp magit-version.el
%{_magit_make} all

%install
%{_magit_make} install
rm %{buildroot}/%{_datadir}/doc/magit/AUTHORS.md

%post
%install_info --info-dir=%{_infodir} %{_infodir}/magit.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/magit-popup.info.gz

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/magit.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/magit-popup.info.gz

%files
%defattr(-,root,root,-)
%doc README.md
%doc Documentation/AUTHORS.md
%{_lispdir}/magit*.el
%{_lispdir}/magit*.elc
%{_lispdir}/git-commit.el
%{_lispdir}/git-commit.elc
%{_lispdir}/git-rebase.el
%{_lispdir}/git-rebase.elc
%{_infodir}/magit.info.gz

%changelog
* Mon Oct  8 2018 auxsvr@gmail.com
- Upgrade to 2.13.0
  * The obsolete option `magit-no-confirm-default' has been removed.
  * Augmenting a file- or blob-visiting buffer with blame information
    was completely rewritten, making the implementation more robust and
    adding many new features.  It is now possible blame in order to get
    an answer to the question "what commits remove these lines".  It is
    no longer necessary for the buffer to be put into `read-only-mode',
    when displaying blame information.  New visualization styles were
    added and users can define their own styles.  New commands to visit
    blobs related to the current chunk were added.
  * Added new command `magit-tag-release'.  This is a fairly opinionated
    command and its only use to you might be to serve as a template for
    your own variant.
  * Added new section inserter `magit-insert-ignored-files', which
    could be added to `magit-status-sections-hook'.
  * The mode `global-magit-file-mode' is now enabled by default, making
    the `magit-file-popup' available on "C-c M-g".  0ec28b97
  * Added new commands `magit-log-trace-definition' and
    `magit-diff-trace-definition', which show a log with diffs about the
    definition at point.  #2588
  * Added new commands `magit-edit-line-commit' and
    `magit-diff-edit-hunk-commit', which allow editing the commit that
    added the line at point.  febe79ba 22b13337
  * The interactive prompts for the various reset commands now indicate
    the branch which is going to be reset.  #3438
  * Added new option `magit-published-branches', providing an additional
    safety-net.  If you try to modify a commit that has been pushed to
    one of these branches already, then you are now being asked whether
    you really want to do that.  Do not rely on this exclusively, there
    are edge-cases that are ambiguous and are not always handled as you
    might have expected.  add4a7f3 ff
  * Gravatar images are now being inserted asynchronously.  #3452
  * After deleting the current worktree, `magit-delete-worktree' now
    shows the status buffer for another worktree.  d9cd4611
  * Added new command `magit-worktree-checkout-pull-request'.  a3d788ec
  * New variable `magit-get-previous-branch-timeout' limits the amount
    of time spent in `magit-get-previous-branch'.  #3457
* Fri Dec  1 2017 auxsvr@gmail.com
- Upgrade to 2.11.0
  * Remove disable-tramp-related-regression-tests.patch, as the tramp test
  no longer requires sudo.
* Fri Mar 18 2016 psimons@suse.com
- Clean up the installed documentation.
* Mon Feb 15 2016 psimons@suse.com
- inital version 2.5.0
  * disable-tramp-related-regression-tests.patch disables on particular test in
  the regression test suite that requires sudo and network access to succeed.
